/* 对齐 DTK Menu（FlowStyle: radius=12, item.radius=6, padding=6, topPadding=8, item.height=30） */
:root {
    --vn-menu-radius: 12px;
    --vn-menu-item-radius: 6px;
    --vn-menu-padding: 8px 6px;
    --vn-menu-item-height: 30px;
}

/* 浮动工具栏 */
.popover {
    background-color: transparent;
    color: #fff;
    border: none;
    box-shadow: none;
    border-radius: 0px;
}

.arrow {
    display: none !important;
}

.note-editor .note-toolbar>.note-btn-group,
.note-popover .popover-content>.note-btn-group {
    margin-top: 0;
    margin-left: -1px;
    margin-right: 1px;
}

.note-editor .note-toolbar,
.note-popover .popover-content {
    display: inline-block;
    padding: 4px 6px 4px 6px !important;
    min-height: 40px;
    height: auto;
    background: rgba(245, 245, 245, 1);
    border: 1px solid rgba(0, 0, 0, 0.04);
    border-radius: var(--vn-menu-radius);
    box-shadow: 0px 6px 20px 0px rgba(0, 0, 0, 0.1);
}

.panel-default>.panel-heading {
    border: none;
}

p {
    margin: 0 !important;
    word-wrap: break-word;
}

.voiceRightMouse {
    width: 0;
    height: 125px;
    overflow: hidden;
    box-shadow: 0 1px 1px #888, 1px 0 1px #ccc;
    position: absolute;
    background-color: #fff;
}

.menu {
    width: 130px;
    height: 25px;
    line-height: 25px;
    padding: 0 10px;
}

/* 下拉按钮 */
.note-popover .popover-content .note-color .dropdown-toggle {
    padding-top: 4px !important;
    padding-left: 1px;
    width: 12px;
    height: 30px !important;
}

.note-current-color-button {
    padding-right: 0px !important;
    width: 30px;
}

.tooltip-inner {
    border-radius: 8px;
    background-color: #F0F2F4 !important;
    color: #000;
    margin-bottom: 1px;
    overflow: hidden;
    box-shadow: 0px 3px 10px 1px rgba(0, 0, 0, 0.15);
    border: 1px solid rgba(0, 0, 0, 0.05);
}

.tooltip.in {
    opacity: 1;
}

.tooltip-arrow {
    display: none;
}

.iconImgStyle {
    width: 20px;
    height: 20px;
}

.colorDiv {
    height: 2px;
    border: 1px solid #000;
}

/* 调色盘和颜色按钮 */
.note-color-btn {
    margin: 5px 2px !important;
    width: 22px !important;
    height: 22px !important;
    border: 1px solid rgba(0, 0, 0, 0.20);
    border-radius: 8px;
}

.note-icon-caret {
    color: rgba(65, 77, 104, 1)
}

.dropdown-menu {
    background: rgba(238, 238, 238, 1);
    width: 153px;
    border: 1px solid rgba(255, 255, 255, 0.1);
    border-radius: var(--vn-menu-radius);
    box-shadow: 0px 6px 16px 0px rgba(0, 0, 0, 0.20);
    top: 115%;
    left: -12px;
}

.note-palette {
    padding: 5px 10px;
    margin: 0px !important;
}

.note-popover .popover-content .note-color .dropdown-menu .note-palette {
    width: 153px;
}

.note-popover .popover-content .note-color .dropdown-menu .note-palette .note-color-row {
    height: 32px;
}

.note-popover .popover-content .note-color-palette div .note-color-btn {
    border-color: rgba(0, 0, 0, 0.2);
    /* border: none; */
    outline: none;
}

.note-color-back .note-color-palette .note-color-btn {
    position: relative;
}

.note-color-back .note-color-palette .note-color-btn::before {
    content: '';
    position: absolute;
    top: 50%;
    left: 50%;
    width: 110%;
    height: 1px;
    background-color: transparent;
    transform: translate(-50%, -50%) rotate(135deg);
    pointer-events: none; /* 确保斜线不会影响按钮的点击事件 */
}

.note-color-back .note-color-palette .note-color-row:first-child .note-color-btn:first-child::before {
    background-color: #00000040;
}

.colorFont {
    color: rgba(65, 77, 104, 1);
    margin: 3px;
    font-size: 12px;
}

.selectColor {
    border: 1px solid #FFF !important;
    /* outline: 1px outset #0883FB; */
    box-shadow: 0 0 0 1.5px #0883FB;
    transform: scale(1.08);
}

.note-holder-custom {
    font-size: 0px;
    display: inline-block;
}

.planButton {
    font-size: 0px;
    vertical-align: top;
    display: inline-block;
    margin: 0px;
}

.planButton button {
    margin: 5px !important;
    width: 43px !important;
    height: 22px;
    opacity: 0.8;
    background: rgba(0, 0, 0, 0.10);
    border-radius: 8px;
    outline: none !important;
}

.planPoa {
    height: 250px;
}

ol,
ul {
    margin-bottom: 0px;
    padding-left: 20px;
}

.dropdown-fontsize {
    width: 50px;
}

/* 默认 button 按键:  hover事件, 按下事件 */
.btn-default {
    border-color: #fff !important;
    outline: none !important;
    background-color: transparent;
    border: none;
    color: rgb(83, 96, 118);
}

.btn:active,
.btn.active {
    box-shadow: 0px 1px 0px 0px rgba(0, 0, 0, 0.2) !important;
}

.btn-default:active,
.btn-default.active,
.open>.dropdown-toggle.btn-default {
    background-color: rgba(0, 0, 0, 0.1) !important;
}

.btn-default:hover:active {
    background-color: rgba(0, 0, 0, 0.2) !important;
    box-shadow: none;
}

/* 浮动工具栏按钮 */
.note-btn-group button {
    height: 30px;
}

.note-btn-group .note-btn {
    padding-top: 2px !important;
    /* 调整图标上下间距，使居中 */
    width: 30px;
}

.note-forecolor {
    padding-right: 4px !important;
}

.note-fontsize button {
    padding-bottom: 2px !important;
}

.note-fontname button {
    padding-bottom: 2px !important;
}

.note-color-back .dropdown-toggle {
    padding-bottom: 2px !important;
}

.note-editable {
    padding: 20px 20px 0 30px;
    padding-bottom: 50px;
}

.note-editable img {
    padding: 4px !important;
    max-width: 100% !important;
}

.slopingside {
    height: 0px;
    border: 1px solid red;
    width: 20px;
    transform: rotate(45deg);
    display: none;    /* TODO: remove slash, impl later */
}

.note-backcolor .backColor-dropdown,
.note-forecolor .foreColor-dropdown {
    padding-right: 2px !important;
}

.heightNull {
    height: 0px !important;
    overflow: hidden;
}

.dropdown-fontsize {
    overflow: hidden;
    overflow-y: auto;
    width: 96px;
    padding: var(--vn-menu-padding);
}

.dropdown-fontname {
    overflow: hidden;
    overflow-y: auto;
    max-height: 300px;
    min-width: 220px !important;
    padding: var(--vn-menu-padding);
}

.dropdown-fontsize>li,
.dropdown-fontname>li {
    width: 100%;
}

.dropdown-fontsize>li>a,
.dropdown-fontname>li>a {
    display: block;
    box-sizing: border-box;
    width: 100%;
    height: var(--vn-menu-item-height);
    line-height: var(--vn-menu-item-height);
    max-width: none !important;
    margin: 0;
    padding: 0 10px;
    border-radius: var(--vn-menu-item-radius);
    color: var(--vn-menu-item-fg, inherit);
}

.dropdown-fontsize>li:nth-last-child(1) a {
    border-bottom: none;
}

.dropdown-fontname>li:nth-last-child(1) a {
    border-bottom: none;
}

.note-popover .popover-content .dropdown-menu.note-check li a i {
    padding-right: 5px;
    color: inherit;
    visibility: hidden;
}

.note-popover .popover-content .dropdown-menu.note-check li a.checked i {
    visibility: visible;
}

.note-air-popover {
    max-width: 100% !important;
    margin: 0 auto !important;
}

/* hover / 选中：主题色底 + 白字，对齐 DTK 菜单样式 */
.dropdown-fontsize>li>a:hover,
.dropdown-fontname>li>a:hover,
.dropdown-fontsize>li>a.checked,
.dropdown-fontname>li>a.checked,
.note-popover .popover-content .dropdown-fontsize>li>a:hover,
.note-popover .popover-content .dropdown-fontname>li>a:hover,
.note-popover .popover-content .dropdown-fontsize>li>a.checked,
.note-popover .popover-content .dropdown-fontname>li>a.checked {
    background-color: var(--vn-menu-hover-bg, rgba(0, 0, 0, 0.08));
    color: #fff !important;
}

.btn-group.open .dropdown-toggle {
    box-shadow: none;
}

.note-editor .note-toolbar>.note-btn-group,
.note-popover .popover-content>.note-line {
    margin-right: 5px;
    margin-left: 4px;
    height: 20px;
    width: 1px;
    background-color: rgba(0, 0, 0, 0.1);
}

.focusAddress {
    width: 0;
    height: 0px;
    vertical-align: bottom;
}

.transparentColor {
    color: transparent !important;
}

.backColorInhert {
    background-color: inherit;
}


/* 定制组件，浮动工具栏 */
.note-popover.popover {
    margin-left: 4%;
    margin-right: 4%;
    max-width: 70%;
}

/***** 字体名称/大小按钮 *****/
.fontsizeBut {
    display: flex;
    align-items: center;
    flex-direction: row;
    justify-content: space-between;
    width: 40px !important;
    height: 30px;
}

.fontsizeBut .note-current-fontsize {
    padding-left: 5px !important;
    color: #000;
}

.fontnameBut {
    display: flex;
    align-items: center;
    flex-direction: row;
    justify-content: space-between;
    width: 74px !important;
    height: 30px;
}

.fontnameBut .note-current-fontname {
    padding-left: 5px !important;
    display: inline-block;
    vertical-align: middle;
    width: auto;
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    color: #000;
}

.fontsizeBut .icon-down,
.fontnameBut .icon-down {
    padding-top: 4px;
}

/* 字体下拉按钮 */
.btn-sm,
.btn-group-sm>.btn {
    padding: 0px !important;
    border-radius: var(--vn-menu-item-radius);
}

/* 新UI设计，按钮和下拉菜单均有圆角，覆盖原始样式 */
.btn-group>.btn:first-child:not(:last-child):not(.dropdown-toggle) {
    border-top-right-radius: var(--vn-menu-item-radius);
    border-bottom-right-radius: var(--vn-menu-item-radius);
}

.btn-group>.btn:last-child:not(:first-child),
.btn-group>.dropdown-toggle:not(:first-child) {
    border-top-left-radius: var(--vn-menu-item-radius);
    border-bottom-left-radius: var(--vn-menu-item-radius);
}

/***** 字体名称/大小按钮 End *****/
