@charset "UTF-8";
	/* * {
	margin:0;
	padding:0
} */
body,html {
	font-size:14px;
	font-family:Helvetica,Arial,'PingFang SC','Hiragino Sans GB','Source Han Sans CN',Roboto,'Heiti SC','Microsoft Yahei',sans-serif;
	/* background:#FCF9FC; */
	width: 100%;
	height: 100%;
	overflow: auto;
}
body::-webkit-scrollbar-track,.note-codable:-webkit-scrollbar-track {
    -webkit-box-shadow:inset 0 0 6px rgba(0,0,0,0);
    background-color:rgba(0,0,0,0)
}
body::-webkit-scrollbar,.note-codable::-webkit-scrollbar {
    width:10px;
    height:10px;
}
body::-webkit-scrollbar:horizontal,.note-codable::-webkit-scrollbar:horizontal{
    height:10px
}
body::-webkit-scrollbar-thumb,.note-codable::-webkit-scrollbar-thumb{
    border-radius: 5px;
    border-style: dashed;
    background-color: rgba(83,96,118,.4);
    border-color: transparent;
    border-width: 2px;
    background-clip: padding-box;
}
body::-webkit-scrollbar-thumb:hover,.note-codable::-webkit-scrollbar-thumb:hover{
    border-width: 1px;
    background-color:rgba(83,96,118,.5);
    border-radius:5px;
    /* -webkit-box-shadow:inset 0 0 6px rgba(83,96,118,.5) */
}
body::-webkit-scrollbar-thumb:active,.note-codable::-webkit-scrollbar-thumb:active{
    border-width: 1px;
    background-color:rgba(83,96,118,.6);
    border-radius:5px;
    /* -webkit-box-shadow:inset 0 0 6px rgba(83,96,118,.6) */
}
body.history-body,body.bookmarks {
	background:rgba(0,0,0,0.03);
}
/* li,ol,ul {
	list-style:none
} */
button,input{
	outline: none;
  	outline-color: rgba(255,255,255,0);
}
div.main-wrapper .top-info {
	width:100%
}
div.main-wrapper .top-info:before {
	display:block;
	content:'';
	width:100%;
	height:60px
}
div.main-wrapper .top-info .inner-fixed {
	width:100%;
	height:50px;
	overflow:hidden;
	box-shadow:0 0 10px rgba(0,0,0,.1);
	background:#FFF;
	padding: 0 20px 0 30px;
	box-sizing:border-box;
	position:fixed;
	top:0;
	left:0;
	z-index:200
}
div.main-wrapper .top-info .inner-fixed:after {
	display:block;
	content:'';
	clear:both
}
div.main-wrapper .top-info .left,div.main-wrapper .top-info .middle,div.main-wrapper .top-info .right {
	padding: 7px 15px;
	box-sizing: border-box;
}
div.main-wrapper .top-info  .middle {
	width: 100%;
    margin: 0 auto;
	box-sizing: border-box;
	overflow: hidden;
	padding: 7px 0 0 0;
}
div.main-wrapper .top-info .left {
	padding-left:25px;
	position:absolute;
	left:0;
	top:0;
	z-index:1
}
div.main-wrapper .top-info .left h2 {
	font-size:18px;
	color:#333;
	font-weight:400;
	line-height:40px;
	letter-spacing:1px
}
div.main-wrapper .top-info .middle .search-box {
	width:524px;
	height:36px;
	box-sizing:border-box;
	position: absolute;
	left: 50%;
    margin-left: -262px;
}
div.main-wrapper .top-info h2 {
	float: left;
	font-size:17px;
	font-family:SourceHanSansSC-Medium,SourceHanSansSC;
	font-weight:600;
	color:rgba(0,26,46,1);
	line-height: 38px;
}
div.main-wrapper .top-info .operator {
	float: right;
	height:100%;
}
div.main-wrapper .top-info .operator button.btn-clear {
	width:135px;
	height:36px;
	background:linear-gradient(180deg,rgba(230,230,230,1) 0%,rgba(227,227,227,1) 100%);
	box-shadow:0px 2px 4px 0px rgba(0,0,0,0.05);
	border-radius:8px;
	border:1px solid rgba(0,0,0,0.03);
	font-size:14px;
	font-family:SourceHanSansSC-Medium,SourceHanSansSC;
	font-weight:500;
	color:rgba(65,77,104,1);
	line-height: 36px;
	box-sizing: content-box;
	cursor: pointer;
}
div.main-wrapper .top-info .operator button.btn-clear:hover {
	opacity:.9
}
div.main-wrapper .top-info .operator button.bookmark-btn {
	cursor: pointer;
	display: inline-block;
	width:100px;
	height:36px;
	background:rgba(0,0,0,0.08) linear-gradient(180deg,rgba(230,230,230,1) 0%,rgba(227,227,227,1) 100%);
	box-shadow:0px 2px 4px 0px rgba(0,0,0,0.05);
	border-radius:8px;
	border:1px solid rgba(0,0,0,0.03);
	margin-left: 10px;
	font-size: 14px;
    font-family: SourceHanSansSC-Medium,SourceHanSansSC;
    font-weight: 500;
    color: rgba(76,87,117,1);
}
div.main-wrapper .top-info .operator button.bookmark-btn:hover {
	opacity:.9
}
.blurplaceholder {
	height: 36px;
    width: 524px;
    position: absolute;
    background-color: rgba(0, 0, 0, 0.08);
    border-radius: 8px;
    text-align: center;
    cursor: text;
}
.search-icon {
    display: inline-block;
    width: 28px;
    height: 26px;
    background-position: -60px 6px;
	background-repeat: no-repeat;
	background-image: url(../images/icon.png);
}
.text-content {
    position: relative;
    top: -2px;
    font-size: 14px;
    font-family: SourceHanSansSC-Medium, SourceHanSansSC;
    font-weight: 500;
    color: #555555;
}
.del-term {
	position: absolute;
    display: none;
    width: 20px;
    height: 24px;
    top: 6px;
    left: 500px;
    background-repeat: no-repeat;
	background-position: -67px -41px;
	background-image: url(../images/icon.png);
	cursor: pointer;
}
.starred {
	-webkit-margin-start: 4px;
    background: url(../images/star_small.png) no-repeat;
    display: inline-block;
    height: 11px;
	width: 11px;
	position: relative;
	top: 2px;
	cursor: pointer;
}
div.main-wrapper .top-info .middle .search-box input.ipt {
	width: 524px;
    height: 36px;
    background: #fff;
    border-radius: 8px;
    outline: none;
	padding-left: 10px;
	border: 2px solid #0081ff;
	display: none;
	box-sizing: border-box;
}

div.main-wrapper .top-info .right {
	position:absolute;
	top:0;
	right:0;
	z-index:1
}

div.main-wrapper .inner-content {
	width:1000px;
	margin:0 auto;
	padding: 10px 0 0 0;
}

#editInfo {
	padding-left: 45px;
	overflow: hidden;
}
#editInfo img {
	float: left;
	padding-top: 5px;
}
#editInfo input {
	float: left;
}
ul.list li div.left a:hover {
	color:#3367D6
}
ul.list li.history-item div.left a:hover {
	color: #000000
}

div.context-menu-wrap {
	width: 226px;
	border-radius:8px;
	overflow:hidden;
	position:fixed;
	z-index:999999;
	background:rgba(255,255,255,0.95);
	box-shadow:0px 6px 20px 0px rgba(0,0,0,0.2);
	border-radius:18px;
	border:1px solid rgba(0,0,0,0.05);
}
/* div.context-menu-wrap:after {
	content: "";
	display: block;
	width: 100%;
	height: 100%;
	position: absolute;
	left: 0;
	top: 0;
	right: 0;
	bottom: 0;
} */
div.context-menu-wrap ul.list {
	position: relative;
	width: 100%;
	border-top: 2px solid rgba(0,0,0,0.2);
}
div.context-menu-wrap ul.list:nth-of-type(1) {
	border-top: none;
}
div.context-menu-wrap ul.list .context-li {
	border: 0;
	width: 100%;
	line-height: 34px;
	font-size: 14px;
	color:#000;
	white-space:nowrap;
	cursor:pointer;
	text-indent: 32px;
	background: transparent;
	text-align: left;
}
div.context-menu-wrap ul.list .disabled-li {
	color: rgba(0, 0, 0, .3);
}
div.context-menu-wrap ul.list input:hover {
	background: #0081FF;
	color:#FFF
}
div.context-menu-wrap ul.list .disabled-li:hover {
	background: transparent;
	color: rgba(0, 0, 0, .3);
}
#search-tab {
	display: none;
}
.search-title {
	min-height: 36px;
    font-size: 20px;
    color: #3c8aee;
    text-shadow: 0 -1px 0 #c7dbf5;
    font-weight: 500;
	visibility: visible;
	padding-left: 55px;
}
.fav-li span {
	cursor: default;
}
.mark-link {
	display: inline-block;
	max-width: 500px;
    overflow: hidden;
    text-overflow: ellipsis;
	white-space: nowrap;
	line-height: 20px;
	float: left;
}
.hide {
	display: none;
}
.list-box {
	position: relative;
	overflow: auto;
}
.history-empty {
	margin-top: 250px;
    right: 0;
    left: 0;
    padding: 0;
    text-align: center;
    position: relative;
	font-size:20px;
	font-family:SourceHanSansSC-Normal,SourceHanSansSC;
	font-weight:400;
	color:rgba(85,85,85,0.4);
    overflow: hidden;
    text-overflow: ellipsis;
    white-space: nowrap;
    font-size: 20px;
}
.history-new .his-check {
	display: none;
}
.history-new .check-label {
	display: block;
	position: absolute;
	width: 20px;
	height: 20px;
	top: 50%;
	margin-top: -10px;
	left: -27px;
	background: url(../images/checkbox-gray.png) no-repeat center center;
	background-size: 100% 100%;
	cursor: pointer;
}
.checked .check-label {
	background-image: url(../images/checkbox-checked.png);
}
.history-new .cell.list-wrap  .list-box ul.list li:hover {
	background:rgba(0,0,0,0.2);
	border-radius:8px;
}
.history-new .cell.list-wrap  .list-box ul.list li:active{
	background:rgba(0,129,255,1);
	box-shadow:0px 4px 6px 0px rgba(44,167,248,0.4);
	border-radius:8px;
}
.history-new li:active div.left a {
	color: #fff;
}
.history-new li:active .host {
	color: #fff;
}
.history-new li:active div.right span.gray {
	color: #fff;
}
.top-fix {
	width: 100%;
	height: 50px;
	position: fixed;
	top: 0;
	left: 0;
	background: #fff;
	line-height: 50px;
	z-index: 999;
	display: none;
}
.top-fix .content {
	width: 100%;
	height: 100%;
	margin: 0 auto;
	overflow: hidden;
	padding: 0 20px 0 30px;
	box-sizing: border-box;
}
.content-left {
	float: left;
	padding-left: 18px;
	font-size:14px;
	font-family:SourceHanSansSC-Medium,SourceHanSansSC;
	font-weight:500;
	color:rgba(65,77,104,1);
}
.content-right {
	float: right;
}
.content-right span {
	display: inline-block;
	width:100px;
	height:36px;
	background:rgba(0,0,0,0.08) linear-gradient(180deg,rgba(230,230,230,1) 0%,rgba(227,227,227,1) 100%);
	box-shadow:0px 2px 4px 0px rgba(0,0,0,0.05);
	border-radius:8px;
	border:1px solid rgba(0,0,0,0.03);
	font-size:14px;
	font-family:SourceHanSansSC-Medium,SourceHanSansSC;
	font-weight:500;
	color:#414D68;
	text-align: center;
	line-height: 36px;
	cursor: pointer;
}
.content-right span.checked-del {
	background:rgba(0,0,0,0.08) linear-gradient(180deg,rgba(37,183,255,1) 0%,rgba(0,152,255,1) 100%);
	box-shadow:0px 4px 4px 0px rgba(0,145,255,0.3);
	color: #fff;
	margin-left: 10px;
}
.set-tips {
	width: 100%;
	height: 26px;
	position: fixed;
	top: 0;
	left: 0;
	z-index: 55;
	background:rgba(0,129,255,0.95);
	line-height: 26px;
	text-align: center;
	font-size:14px;
	font-family:SourceHanSansSC-Medium,SourceHanSansSC;
	font-weight:500;
	color:rgba(255,255,255,1);
	display: none;
}