:root {
    --color: rgba(65, 77, 104, 1);
    --highlightColor: rgb(0, 91, 255);
    --backgroundColor: rgba(255, 255,255, 0.7);
}

body {
    padding: 0px;
    line-height: 1.72;
    font-family: 'Helvetica';
    background-color: var(--backgroundColor);
    color: rgba(0, 0, 0, 1);
    word-wrap: break-word;
}

.demo {
    padding: 12px 0;
    border-radius: 10px;
    box-sizing: border-box;
    background-color: transparent !important;
}

.demo>div {
    display: inline-block;
    vertical-align: bottom;
}

.lf {
    margin: 2px 0 0 2px;
    position: absolute;
}

.lr {
    float: right;
    margin: 0px 20px 0 0;
}

.li {
    font-weight: normal !important;
    font-style: normal !important;
    text-decoration: none !important;
    font-size: 14px;
    background: rgba(0, 0, 0, 0.05);
    min-height: 30px;
    border-radius: 12px;
    margin-bottom: 10px;
    margin-top: 10px;
}

.active {
    background: rgba(0, 129, 255, 0.5);
}

.voicebtn {
    border-radius: 50%;
    width: 40px;
    height: 40px;
    background-color: #0183FF;
    margin: 0 20px 0 20px;
    cursor: pointer;
    overflow: hidden;
    box-shadow: 0px 4px 6px 0px #94c8fa80;
}

.voicebtn:hover::before {
    content: "";
    position: absolute;
    width: 40px;
    height: 40px;
    border-radius: 50%;
    background-color: rgba(255, 255, 255, 0.2);
}

.voicebtn:active::before {
    content: "";
    position: absolute;
    width: 40px;
    height: 40px;
    border-radius: 50%;
    background-color: rgba(0, 0, 0, 0.2);
}

.voicebtn.play {
    background-image: url(./img/play.svg);
    background-size: contain;
}

.voicebtn.pause {
    background-image: url(./img/pause.svg);
    background-size: contain;
}

.title {
    color: rgba(0, 26, 46, 1);
    font-size: 14px !important;
    line-height: 16px;
}

.minute {
    color: rgba(138, 161, 180, 1);
    font-size: 12px !important;
    line-height: 12px;
    margin-top: 5px;
}

.time {
    color: rgba(65, 77, 104, 1);
    font-size: 12px !important;
    line-height: 12px;
}

.demo::selection, .lf::selection, .title::selection, .minute::selection, .time::selection {
    background: transparent !important;
    color: inherit;
}

/* 字体大小固定 */

.title span {
    font-size: 14px !important;
}

.minute span {
    font-size: 12px !important;
}

.time span {
    font-size: 12px !important;
}

.padtop {
    padding-top: 6px;
}

.translate {
    line-height: 20px;
    font-size: 12px;
    position: relative;
}

.translate>div {
    text-align: center;
    color: rgba(65, 77, 104, 1) !important;
}

.icon {
    height: 21px;
    position: relative;
}

@keyframes fadeInOut {
    0% {
        opacity: 0;
        /*初始状态 透明度为0/
        }
        100% {
            opacity: 1; /*结尾状态 透明度为1*/
    }
}

.noselect {
    user-select: none;
    padding: 5px 20px 10px 20px;
    visibility: hidden
}

.showTextBox {
    position: absolute;
    padding: 5px 20px 10px 20px;
    user-select: none;
    left: 50%;
    top: 0;
    transform: translateX(-50%);
}

::selection {
    color: #fff;
}

u {
    text-decoration-color: transparent !important;
    border-bottom: 1px solid rgba(65, 77, 104, 1);
}

strike {
    text-decoration-color: rgba(65, 77, 104, 1);
}

strike[style="text-decoration-line: underline;"] {
    text-decoration-color: transparent !important;
    border-bottom: 1px solid rgba(65, 77, 104, 1);
}

/* 位图字体（如文泉驿点阵正黑、Unifont）无粗体变体，font-weight:bold 不产生视觉变化。
   使用零模糊 text-shadow 偏移像素合成加粗效果，不影响矢量字体的正常粗体渲染。
   注意：此规则仅限编辑器内容区域，零模糊不产生额外合成层，无性能影响。 */
.note-editable b, .note-editable strong {
    text-shadow: 0.5px 0 0 currentColor;
}
